function [C B L Ls] = PCA(X)
%[C B L Ls] = PCA(X);
%
%PCA returns the eigenvectors and the eigenvalues, and is a computationally
%efficient version of the singular-value decomposition, which is also known 
%as the Karhunen-Loeve decomposition, or proper orthogonal decomposition. 
%Ls are the eigenvalies scaled to sum to one.
%
%The Decomposition satisfies the following conditions:
%
%  X = B*X*B';
%  X = C*B';
%
%
%  X is a data matrix. Each row of X should be simultaneously observed. 
%  Therefore X should be of the form:
%
%      [trials observations] = size(X).
%
%
%  C (components) are the principal components:
%
%    C = B*X;
%
%
%  B (basis) are the eigenvectors:
%
%      B(:,k) is the kth eigenvector.
%
%
%  L (lambda) are the eigenvalues:
%
%      L(k) >= L(k+1).
%
%
%  Ls (lambda scaled) are the scaled eigenvectors:
%
%      Ls = L./sum(L);

Cv = X'*X;
[B LI] = eig(Cv);

L = diag(LI)';
[L ind] = sort(L);
ind = fliplr(ind);

L = fliplr(L);
Ls = L./sum(L);
B = B(:,ind);
C = X*B;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%